Index — Somoclu 1.7.0 documentation

# Index

C | G | L | S | T | U | V

## C

cluster() (Somoclu method)

## G

get_surface_state() (Somoclu method)

## L

load_bmus() (Somoclu method) load_codebook() (Somoclu method) | load_umatrix() (Somoclu method)

## S

Somoclu (built-in class)

## T

train() (Somoclu method)

## U

update_data() (Somoclu method)

## V

view_activation_map() (Somoclu method) view_component_planes() (Somoclu method) | view_similarity_matrix() (Somoclu method) view_umatrix() (Somoclu method)